@@ -110,8 +110,9 @@ class GqylpyCache(type):
         if not_found:
             x = f'{cls.__module__}.{cls.__name__}'
             e = not_found if len(not_found) > 1 else not_found[0]
-            raise type('NotCacheDefineError', (Exception,), {'__module__': __package__}) \
-                (f'The "{__package__}" instance "{x}" has no method "{e}".')
+            raise type(
+                'NotCacheDefineError', (Exception,), {'__module__': __package__}
+            )(f'"{__package__}" instance "{x}" has no method "{e}".')
 
     @staticmethod
     def delete_repeated(data: list):
@@ -168,7 +169,7 @@ class ClassMethodCaller:
 
     def __call__(self, *a, **kw):
         __cache_pool__: dict = self.__sget('__cache_pool__')
-        key: tuple = self.__name__, a, str(kw)
+        key = self.__name__, a, str(kw)
 
         try:
             cache: dict = __cache_pool__[key]
